﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows.DockManager;

namespace TabGroupPaneBinding
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            xamDock1.DataContext = new List<Data>
            {
                new Data { ID = 1, Name = "Item 1" },
                new Data { ID = 2, Name = "Item 2" },
                new Data { ID = 3, Name = "Item 3" },
            };

            tgp.SelectedItem = tgp.Items[1];
        }

        private void SetDocumentHostContent(DocumentContentHost host)
        {
            var rootDocumentPane = host.Panes.First();
            var tabGroupPane = rootDocumentPane.Panes.OfType<TabGroupPane>().First();

            var tradeItem = tabGroupPane.Items.OfType<ContentPane>().FirstOrDefault(p => (p.Header ?? "").ToString() == "Trades");
            var cashReportItem = tabGroupPane.Items.OfType<ContentPane>().FirstOrDefault(p => (p.Header ?? "").ToString() == "Cashflow Report");
            var notionalReportItem = tabGroupPane.Items.OfType<ContentPane>().FirstOrDefault(p => (p.Header ?? "").ToString() == "Reset Notional Report");
            var importItem = tabGroupPane.Items.OfType<ContentPane>().FirstOrDefault(p => (p.Header ?? "").ToString() == "CSV");

            var removeItems = new[] { tradeItem, cashReportItem, notionalReportItem, importItem }.Where(r => r != null).ToList();

            ContentPane firstItem = null;
            var headerToUse = "Test";
            
            if (firstItem != null)
            {
                // reports & trade query tabs need to be preserved - delist them from the remove list
                // imports tab needs to be removed, so keep that one on the remove list
                if (!firstItem.Equals(importItem))
                {
                    removeItems.Remove(firstItem);
                    firstItem = null;
                }
            }

            var restoreSet = tabGroupPane.Items.OfType<ContentPane>().Where(p => !removeItems.Contains(p)).ToList();

            var itemsToClear = tabGroupPane.Items.OfType<ContentPane>().ToList();
            foreach (var content in itemsToClear)
            {
                tabGroupPane.Items.Remove(content);
            }

            if (firstItem == null)
            {
                // create the new view here and add as a tab
                firstItem = new ContentPane
                {
                    AllowClose = true,
                    AllowDockingFloating = false,
                    AllowFloatingOnly = false,
                    AllowDocking = false,
                    AllowInDocumentHost = true,
                    AllowDockingInTabGroup = false,
                    CloseButtonVisibility = Visibility.Visible,
                    PinButtonVisibility = Visibility.Collapsed,
                    WindowPositionMenuVisibility = Visibility.Collapsed,
                    Content = new TextBox() { Text= "Content Pane"},
                    Header = headerToUse
                };

                restoreSet.Insert(0, firstItem);
            }
            else
            {
                firstItem.Content = new TextBox() { Text = "Content" };
            }

            foreach (var contentPane in restoreSet)
            {
                tabGroupPane.Items.Add(contentPane);
            }
            tabGroupPane.SelectedItem = firstItem;
            
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            SetDocumentHostContent(dch);
        }

    }

    public class Data
    {
        public int ID { get; set; }
        public string Name { get; set; }
    }

}
